import * as React from 'react';
import { useWave, useLayoutEffect } from './hook';
export const MotionWave = React.memo(React.forwardRef((props, ref) => {
    const { width = innerWidth, height = innerHeight, initialConfig, motionConfig, ...restProps } = props;
    const defaultConfig = React.useMemo(() => initialConfig, []);
    const [canvasRef, canvasHandler] = useWave(defaultConfig, ref);
    const motionMap = React.useRef({});
    useLayoutEffect(() => {
        if (motionConfig && canvasHandler.current) {
            Object.entries(motionConfig).forEach(([key, config]) => {
                const motionKey = key;
                const currentValue = canvasHandler.current.currentConfig[motionKey];
                let nextValue, transition;
                if (typeof config === 'object' && config !== null) {
                    const { value, ...nextTransition } = config;
                    nextValue = value;
                    transition = nextTransition;
                }
                else {
                    nextValue = config;
                    transition = {};
                }
                const { transition: lastTransition, controls: lastControls } = motionMap.current[motionKey] ?? {};
                const shouldAnimate = (lastTransition &&
                    JSON.stringify(lastTransition) !== JSON.stringify(transition)) ||
                    (currentValue !== undefined && currentValue !== nextValue);
                if (shouldAnimate) {
                    lastControls?.stop();
                    const controls = canvasHandler.current.motionTo(motionKey, nextValue, {
                        ...transition,
                    });
                    motionMap.current[motionKey] = {
                        controls,
                        transition: transition,
                    };
                }
            });
        }
    }, [JSON.stringify(motionConfig)]);
    useLayoutEffect(() => {
        return () => {
            if (motionMap.current) {
                Object.values(motionMap.current).forEach(({ controls }) => {
                    controls.stop();
                });
            }
        };
    }, []);
    return (React.createElement("canvas", { ref: canvasRef, width: width, height: height, ...restProps }));
}));
